@@ -435,6 +435,14 @@ public class UnicodeProperties {
         new CodeRangeEntry("sogd", "CR_Sogdian"),
         new CodeRangeEntry("oldsogdian", "CR_Old_Sogdian"),
         new CodeRangeEntry("sogo", "CR_Old_Sogdian"),
+        new CodeRangeEntry("elymaic", "CR_Elymaic"),
+        new CodeRangeEntry("elym", "CR_Elymaic"),
+        new CodeRangeEntry("nandinagari", "CR_Nandinagari"),
+        new CodeRangeEntry("nand", "CR_Nandinagari"),
+        new CodeRangeEntry("nyiakengpuachuehmong", "CR_Nyiakeng_Puachue_Hmong"),
+        new CodeRangeEntry("hmnp", "CR_Nyiakeng_Puachue_Hmong"),
+        new CodeRangeEntry("wancho", "CR_Wancho"),
+        new CodeRangeEntry("wcho", "CR_Wancho"),
         new CodeRangeEntry("whitespace", "CR_Space"),
         new CodeRangeEntry("wspace", "CR_Space"),
         new CodeRangeEntry("bidicontrol", "CR_Bidi_Control"),
@@ -527,6 +535,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("age=9.0", "CR_Age_9_0"),
         new CodeRangeEntry("age=10.0", "CR_Age_10_0"),
         new CodeRangeEntry("age=11.0", "CR_Age_11_0"),
+        new CodeRangeEntry("age=12.0", "CR_Age_12_0"),
         new CodeRangeEntry("graphemeclusterbreak=prepend", "CR_Grapheme_Cluster_Break_Prepend"),
         new CodeRangeEntry("graphemeclusterbreak=cr", "CR_Grapheme_Cluster_Break_CR"),
         new CodeRangeEntry("graphemeclusterbreak=lf", "CR_NEWLINE"),
@@ -756,6 +765,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("inruminumeralsymbols", "CR_In_Rumi_Numeral_Symbols"),
         new CodeRangeEntry("inoldsogdian", "CR_In_Old_Sogdian"),
         new CodeRangeEntry("insogdian", "CR_In_Sogdian"),
+        new CodeRangeEntry("inelymaic", "CR_In_Elymaic"),
         new CodeRangeEntry("inbrahmi", "CR_In_Brahmi"),
         new CodeRangeEntry("inkaithi", "CR_In_Kaithi"),
         new CodeRangeEntry("insorasompeng", "CR_In_Sora_Sompeng"),
@@ -776,6 +786,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("inahom", "CR_In_Ahom"),
         new CodeRangeEntry("indogra", "CR_In_Dogra"),
         new CodeRangeEntry("inwarangciti", "CR_In_Warang_Citi"),
+        new CodeRangeEntry("innandinagari", "CR_In_Nandinagari"),
         new CodeRangeEntry("inzanabazarsquare", "CR_In_Zanabazar_Square"),
         new CodeRangeEntry("insoyombo", "CR_In_Soyombo"),
         new CodeRangeEntry("inpaucinhau", "CR_In_Pau_Cin_Hau"),
@@ -784,10 +795,12 @@ public class UnicodeProperties {
         new CodeRangeEntry("inmasaramgondi", "CR_In_Masaram_Gondi"),
         new CodeRangeEntry("ingunjalagondi", "CR_In_Gunjala_Gondi"),
         new CodeRangeEntry("inmakasar", "CR_In_Makasar"),
+        new CodeRangeEntry("intamilsupplement", "CR_In_Tamil_Supplement"),
         new CodeRangeEntry("incuneiform", "CR_In_Cuneiform"),
         new CodeRangeEntry("incuneiformnumbersandpunctuation", "CR_In_Cuneiform_Numbers_and_Punctuation"),
         new CodeRangeEntry("inearlydynasticcuneiform", "CR_In_Early_Dynastic_Cuneiform"),
         new CodeRangeEntry("inegyptianhieroglyphs", "CR_In_Egyptian_Hieroglyphs"),
+        new CodeRangeEntry("inegyptianhieroglyphformatcontrols", "CR_In_Egyptian_Hieroglyph_Format_Controls"),
         new CodeRangeEntry("inanatolianhieroglyphs", "CR_In_Anatolian_Hieroglyphs"),
         new CodeRangeEntry("inbamumsupplement", "CR_In_Bamum_Supplement"),
         new CodeRangeEntry("inmro", "CR_In_Mro"),
@@ -800,6 +813,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("intangutcomponents", "CR_In_Tangut_Components"),
         new CodeRangeEntry("inkanasupplement", "CR_In_Kana_Supplement"),
         new CodeRangeEntry("inkanaextendeda", "CR_In_Kana_Extended_A"),
+        new CodeRangeEntry("insmallkanaextension", "CR_In_Small_Kana_Extension"),
         new CodeRangeEntry("innushu", "CR_In_Nushu"),
         new CodeRangeEntry("induployan", "CR_In_Duployan"),
         new CodeRangeEntry("inshorthandformatcontrols", "CR_In_Shorthand_Format_Controls"),
@@ -812,9 +826,12 @@ public class UnicodeProperties {
         new CodeRangeEntry("inmathematicalalphanumericsymbols", "CR_In_Mathematical_Alphanumeric_Symbols"),
         new CodeRangeEntry("insuttonsignwriting", "CR_In_Sutton_SignWriting"),
         new CodeRangeEntry("inglagoliticsupplement", "CR_In_Glagolitic_Supplement"),
+        new CodeRangeEntry("innyiakengpuachuehmong", "CR_In_Nyiakeng_Puachue_Hmong"),
+        new CodeRangeEntry("inwancho", "CR_In_Wancho"),
         new CodeRangeEntry("inmendekikakui", "CR_In_Mende_Kikakui"),
         new CodeRangeEntry("inadlam", "CR_In_Adlam"),
         new CodeRangeEntry("inindicsiyaqnumbers", "CR_In_Indic_Siyaq_Numbers"),
+        new CodeRangeEntry("inottomansiyaqnumbers", "CR_In_Ottoman_Siyaq_Numbers"),
         new CodeRangeEntry("inarabicmathematicalalphabeticsymbols", "CR_In_Arabic_Mathematical_Alphabetic_Symbols"),
         new CodeRangeEntry("inmahjongtiles", "CR_In_Mahjong_Tiles"),
         new CodeRangeEntry("indominotiles", "CR_In_Domino_Tiles"),
@@ -830,6 +847,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("insupplementalarrowsc", "CR_In_Supplemental_Arrows_C"),
         new CodeRangeEntry("insupplementalsymbolsandpictographs", "CR_In_Supplemental_Symbols_and_Pictographs"),
         new CodeRangeEntry("inchesssymbols", "CR_In_Chess_Symbols"),
+        new CodeRangeEntry("insymbolsandpictographsextendeda", "CR_In_Symbols_and_Pictographs_Extended_A"),
         new CodeRangeEntry("incjkunifiedideographsextensionb", "CR_In_CJK_Unified_Ideographs_Extension_B"),
         new CodeRangeEntry("incjkunifiedideographsextensionc", "CR_In_CJK_Unified_Ideographs_Extension_C"),
         new CodeRangeEntry("incjkunifiedideographsextensiond", "CR_In_CJK_Unified_Ideographs_Extension_D"),
